==> tecfy_core_package-1.0.58.tar.gz: lib/models/entity/property_date_time.model.dart <==
part of tecfy_core_client_package;

class PropertyDateTime extends Property {
  DateTime? minDate;
  DateTime? maxDate;

  bool isTodayByDefault = false;

  bool isAllowFuture = true;
  bool isAllowPast = true;

  /// <summary>
  /// yyyy-MM-dd    (default)
  /// dd/MM/yyyy
  /// </summary>
  String format = "yyyy-MM-dd";

  PropertyDateTime(
      {required String dbName,
      required String nameAr,
      required String nameEn,
      bool isRequired = false,
      this.format = 'yyyy-MM-dd',
      this.isTodayByDefault = false})
      : super(
            dbName: dbName,
            nameAr: nameAr,
            nameEn: nameEn,
            propertyType: PropertyTypes.Date,
            valueType: ValueTypes.DateTime,
            isRequired: isRequired);

  PropertyDateTime.fromMap(Map<String, dynamic> row) : super.fromMap(row) {
    minDate = getDateFromJsonString(row['minDate'] ?? '2000-01-01');
    maxDate = getDateFromJsonString(row['maxDate'] ?? '2050-01-01');
    isTodayByDefault = row['isTodayByDefault'] ?? false;
    isAllowFuture = row['isAllowFuture'] ?? true;
    isAllowPast = row['isAllowPast'] ?? true;
    format = row['format'] ?? 'yyyy-MM-dd';
  }

  DateTime? getDateFromJsonString(String value) {
    return BaseModel.parseUTC(value);
    // return DateTime.parse(value,);
  }

  @override
  OperationResult isValid(data) {
    if (!super.isValid(data).success) return super.isValid(data);

    return OperationResult(success: true);
  }

  /// get the value and bind tp display widget
  Widget getDisplayWidget(Map<String, dynamic> data, {TextStyle? textStyle}) {
    return Text(getDisplayText(data), style: textStyle);
  }

  /// get the value and bind tp display widget
  String getDisplayText(Map<String, dynamic> data) {
    if (data[dbName] == null) {
      return '';
    }
    if (valueType == ValueTypes.Number) {
      return data[dbName] == null || data[dbName] == 0
          ? ''
          : intl.DateFormat(format).format(
              DateTime.fromMillisecondsSinceEpoch(data[dbName], isUtc: true));
    } else {
      var date = data[dbName] is DateTime
          ? data[dbName]
          : BaseModel.parseUTC(data[dbName]);
      return date == null ? '' : intl.DateFormat(format).format(date.toLocal());
    }
  }

  Future<bool> getDefaultValue(Map<String, dynamic> data) async {
    if (data[dbName] != null) return false;
    if (isTodayByDefault) {
      data[dbName] = DateTime.now().toUtc();
      return true;
    }
    return false;
  }
}

==> tecfy_core_package-1.2.7.tar.gz: lib/models/entity/property_date_time.model.dart <==
part of tecfy_core_client_package;

class PropertyDateTime extends Property {
  DateTime? minDate;
  DateTime? maxDate;

  bool isTodayByDefault = false;

  bool isAllowFuture = true;
  bool isAllowPast = true;

  /// <summary>
  /// yyyy-MM-dd    (default)
  /// dd/MM/yyyy
  /// </summary>
  String format = "yyyy-MM-dd";

  PropertyDateTime(
      {required String dbName,
      required String nameAr,
      required String nameEn,
      bool isRequired = false,
      this.format = 'yyyy-MM-dd',
      this.isTodayByDefault = false})
      : super(
            dbName: dbName,
            nameAr: nameAr,
            nameEn: nameEn,
            propertyType: PropertyTypes.Date,
            valueType: ValueTypes.DateTime,
            isRequired: isRequired);

  PropertyDateTime.fromMap(Map<String, dynamic> row) : super.fromMap(row) {
    minDate = getDateFromJsonString(row['minDate'] ?? '2000-01-01');
    maxDate = getDateFromJsonString(row['maxDate'] ?? '2050-01-01');
    isTodayByDefault = row['isTodayByDefault'] ?? false;
    isAllowFuture = row['isAllowFuture'] ?? true;
    isAllowPast = row['isAllowPast'] ?? true;
    format = row['format'] ?? 'yyyy-MM-dd';
  }

  DateTime? getDateFromJsonString(String value) {
    return BaseModel.parseUTC(value);
    // return DateTime.parse(value,);
  }

  @override
  OperationResult isValid(data) {
    if (!super.isValid(data).success) return super.isValid(data);

    return OperationResult(success: true);
  }

  /// get the value and bind tp display widget
  Widget getDisplayWidget(Map<String, dynamic> data, {TextStyle? textStyle}) {
    return SelectableText(getDisplayText(data), style: textStyle);
  }

  /// get the value and bind tp display widget
  String getDisplayText(Map<String, dynamic> data) {
    if (data[dbName] == null) {
      return '';
    }
    if (valueType == ValueTypes.Number) {
      return data[dbName] == null || data[dbName] == 0
          ? ''
          : intl.DateFormat(format).format(
              DateTime.fromMillisecondsSinceEpoch(data[dbName], isUtc: true));
    } else {
      var date = data[dbName] is DateTime
          ? data[dbName]
          : BaseModel.parseUTC(data[dbName]);
      return date == null ? '' : intl.DateFormat(format).format(date.toLocal());
    }
  }

  Future<bool> getDefaultValue(Map<String, dynamic> data) async {
    if (data[dbName] != null) return false;
    if (isTodayByDefault) {
      data[dbName] = DateTime.now().toUtc();
      return true;
    }
    return false;
  }
}
